"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.SavedObjectsClientWrapper = void 0;
var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));
var _errors = require("../common/errors");
var _common = require("../common");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0 and the Server Side Public License, v 1; you may not use this file except
 * in compliance with, at your election, the Elastic License 2.0 or the Server
 * Side Public License, v 1.
 */

class SavedObjectsClientWrapper {
  constructor(savedObjectClient) {
    (0, _defineProperty2.default)(this, "savedObjectClient", void 0);
    this.savedObjectClient = savedObjectClient;
  }
  async find(options) {
    const result = await this.savedObjectClient.find({
      ...options,
      type: _common.DATA_VIEW_SAVED_OBJECT_TYPE
    });
    return result.saved_objects;
  }
  async get(id) {
    const response = await this.savedObjectClient.resolve('index-pattern', id);
    if (response.outcome === 'conflict') {
      throw new _errors.DataViewSavedObjectConflictError(id);
    }
    return response.saved_object;
  }
  async getSavedSearch(id) {
    const response = await this.savedObjectClient.resolve('search', id);
    if (response.outcome === 'conflict') {
      throw new _errors.DataViewSavedObjectConflictError(id);
    }
    return response.saved_object;
  }
  async update(id, attributes, options) {
    return await this.savedObjectClient.update(_common.DATA_VIEW_SAVED_OBJECT_TYPE, id, attributes, options);
  }
  async create(attributes, options) {
    return await this.savedObjectClient.create(_common.DATA_VIEW_SAVED_OBJECT_TYPE, attributes, options);
  }
  async delete(id) {
    await this.savedObjectClient.delete(_common.DATA_VIEW_SAVED_OBJECT_TYPE, id, {
      force: true
    });
  }
}
exports.SavedObjectsClientWrapper = SavedObjectsClientWrapper;