"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.KnowledgeBaseBulkImportFlyout = KnowledgeBaseBulkImportFlyout;
var _react = _interopRequireWildcard(require("react"));
var _i18n = require("@kbn/i18n");
var _eui = require("@elastic/eui");
var _i18nReact = require("@kbn/i18n-react");
var _use_import_knowledge_base_entries = require("../../hooks/use_import_knowledge_base_entries");
var _use_kibana = require("../../hooks/use_kibana");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

function KnowledgeBaseBulkImportFlyout({
  onClose
}) {
  const {
    notifications: {
      toasts
    }
  } = (0, _use_kibana.useKibana)().services;
  const {
    mutateAsync,
    isLoading
  } = (0, _use_import_knowledge_base_entries.useImportKnowledgeBaseEntries)();
  const filePickerId = (0, _eui.useGeneratedHtmlId)({
    prefix: 'filePicker'
  });
  const [files, setFiles] = (0, _react.useState)([]);
  const onChange = file => {
    setFiles(file && file.length > 0 ? Array.from(file) : []);
  };
  const handleSubmitNewEntryClick = async () => {
    let entries = [];
    const text = await files[0].text();
    const elements = text.split('\n').filter(Boolean);
    try {
      entries = elements.map(el => JSON.parse(el));
    } catch (_) {
      toasts.addError(new Error(_i18n.i18n.translate('xpack.observabilityAiAssistantManagement.knowledgeBaseBulkImportFlyout.errorParsingEntries.description', {
        defaultMessage: 'Error parsing JSON entries'
      })), {
        title: _i18n.i18n.translate('xpack.observabilityAiAssistantManagement.knowledgeBaseBulkImportFlyout.errorParsingEntries.title', {
          defaultMessage: 'Something went wrong'
        })
      });
    }
    mutateAsync({
      entries
    }).then(onClose);
  };
  return /*#__PURE__*/_react.default.createElement(_eui.EuiFlyout, {
    onClose: onClose,
    "data-test-subj": "knowledgeBaseBulkImportFlyout"
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiFlyoutHeader, {
    hasBorder: true
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiTitle, null, /*#__PURE__*/_react.default.createElement("h2", null, _i18n.i18n.translate('xpack.observabilityAiAssistantManagement.knowledgeBaseBulkImportFlyout.h2.bulkImportLabel', {
    defaultMessage: 'Import files'
  })))), /*#__PURE__*/_react.default.createElement(_eui.EuiFlyoutBody, null, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexGroup, {
    alignItems: "center"
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
    grow: false
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiIcon, {
    type: "addDataApp",
    size: "xl"
  })), /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, null, /*#__PURE__*/_react.default.createElement(_eui.EuiTitle, {
    size: "xs"
  }, /*#__PURE__*/_react.default.createElement("h3", null, _i18n.i18n.translate('xpack.observabilityAiAssistantManagement.knowledgeBaseBulkImportFlyout.addFilesToEnrichTitleLabel', {
    defaultMessage: 'Add files to enrich your Knowledge base'
  }))))), /*#__PURE__*/_react.default.createElement(_eui.EuiSpacer, {
    size: "l"
  }), /*#__PURE__*/_react.default.createElement(_eui.EuiText, {
    size: "s"
  }, /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
    id: "xpack.observabilityAiAssistantManagement.knowledgeBaseBulkImportFlyout.uploadAJSONFileTextLabel",
    defaultMessage: "Upload a newline delimited JSON ({ext}) file containing a list of entries to add to your Knowledge base.",
    values: {
      ext: /*#__PURE__*/_react.default.createElement(_eui.EuiCode, {
        language: "html"
      }, ".ndjson")
    }
  })), /*#__PURE__*/_react.default.createElement(_eui.EuiSpacer, {
    size: "m"
  }), /*#__PURE__*/_react.default.createElement(_eui.EuiText, {
    size: "s"
  }, _i18n.i18n.translate('xpack.observabilityAiAssistantManagement.knowledgeBaseBulkImportFlyout.theObjectsShouldBeTextLabel', {
    defaultMessage: 'The objects should be of the following format:'
  })), /*#__PURE__*/_react.default.createElement(_eui.EuiSpacer, {
    size: "m"
  }), /*#__PURE__*/_react.default.createElement(_eui.EuiCodeBlock, {
    isCopyable: true,
    paddingSize: "s"
  }, `{
  "id": "a_unique_human_readable_id",
  "text": "Contents of item",
}
`), /*#__PURE__*/_react.default.createElement(_eui.EuiHorizontalRule, null), /*#__PURE__*/_react.default.createElement(_eui.EuiFilePicker, {
    "aria-label": _i18n.i18n.translate('xpack.observabilityAiAssistantManagement.knowledgeBaseBulkImportFlyout.euiFilePicker.uploadJSONLabel', {
      defaultMessage: 'Upload JSON'
    }),
    display: "large",
    fullWidth: true,
    id: filePickerId,
    initialPromptText: _i18n.i18n.translate('xpack.observabilityAiAssistantManagement.knowledgeBaseBulkImportFlyout.euiFilePicker.selectOrDragAndLabel', {
      defaultMessage: 'Select or drag and drop a .ndjson file'
    }),
    onChange: onChange
  })), /*#__PURE__*/_react.default.createElement(_eui.EuiFlyoutFooter, null, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexGroup, {
    justifyContent: "spaceBetween"
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
    grow: false
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiButtonEmpty, {
    "data-test-subj": "knowledgeBaseBulkImportFlyoutCancelButton",
    disabled: isLoading,
    onClick: onClose
  }, _i18n.i18n.translate('xpack.observabilityAiAssistantManagement.knowledgeBaseBulkImportFlyout.cancelButtonEmptyLabel', {
    defaultMessage: 'Cancel'
  }))), /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
    grow: false
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiButton, {
    "data-test-subj": "knowledgeBaseBulkImportFlyoutSaveButton",
    fill: true,
    isLoading: isLoading,
    onClick: handleSubmitNewEntryClick
  }, _i18n.i18n.translate('xpack.observabilityAiAssistantManagement.knowledgeBaseBulkImportFlyout.saveButtonLabel', {
    defaultMessage: 'Save'
  }))))));
}