"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.IntervalField = void 0;
var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));
var _react = _interopRequireWildcard(require("react"));
var _fastDeepEqual = _interopRequireDefault(require("fast-deep-equal"));
var _reactHookForm = require("react-hook-form");
var _eui = require("@elastic/eui");
var _i18n = require("@kbn/i18n");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const intervalFieldValidations = {
  required: {
    message: _i18n.i18n.translate('xpack.osquery.pack.queryFlyoutForm.intervalFieldMinNumberError', {
      defaultMessage: 'A positive interval value is required'
    }),
    value: true
  },
  min: {
    message: _i18n.i18n.translate('xpack.osquery.pack.queryFlyoutForm.intervalFieldMinNumberError', {
      defaultMessage: 'A positive interval value is required'
    }),
    value: 1
  },
  max: {
    message: _i18n.i18n.translate('xpack.osquery.pack.queryFlyoutForm.intervalFieldMaxNumberError', {
      defaultMessage: 'An interval value must be lower than {than}',
      values: {
        than: 604800
      }
    }),
    value: 604800
  }
};
const IntervalFieldComponent = ({
  euiFieldProps
}) => {
  const {
    field: {
      onChange,
      value
    },
    fieldState: {
      error
    }
  } = (0, _reactHookForm.useController)({
    name: 'interval',
    defaultValue: 3600,
    rules: {
      ...intervalFieldValidations
    }
  });
  const handleChange = (0, _react.useCallback)(e => {
    const numberValue = e.target.valueAsNumber ? e.target.valueAsNumber : 0;
    onChange(numberValue);
  }, [onChange]);
  const hasError = (0, _react.useMemo)(() => !!(error !== null && error !== void 0 && error.message), [error === null || error === void 0 ? void 0 : error.message]);
  return /*#__PURE__*/_react.default.createElement(_eui.EuiFormRow, {
    label: _i18n.i18n.translate('xpack.osquery.pack.queryFlyoutForm.intervalFieldLabel', {
      defaultMessage: 'Interval (s)'
    }),
    error: error === null || error === void 0 ? void 0 : error.message,
    isInvalid: hasError,
    fullWidth: true
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiFieldNumber, (0, _extends2.default)({
    isInvalid: hasError,
    value: value,
    onChange: handleChange,
    fullWidth: true,
    type: "number",
    "data-test-subj": "osquery-interval-field"
  }, euiFieldProps)));
};
const IntervalField = exports.IntervalField = /*#__PURE__*/_react.default.memo(IntervalFieldComponent, _fastDeepEqual.default);