"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.TelemetryClient = void 0;
var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));
var _constants = require("./constants");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

/**
 * Client which aggregate all the available telemetry tracking functions
 * for the plugin
 */
class TelemetryClient {
  constructor(analytics) {
    (0, _defineProperty2.default)(this, "reportAlertsGroupingChanged", params => {
      this.analytics.reportEvent(_constants.TelemetryEventTypes.AlertsGroupingChanged, params);
    });
    (0, _defineProperty2.default)(this, "reportAlertsGroupingToggled", params => {
      this.analytics.reportEvent(_constants.TelemetryEventTypes.AlertsGroupingToggled, params);
    });
    (0, _defineProperty2.default)(this, "reportAlertsGroupingTakeAction", params => {
      this.analytics.reportEvent(_constants.TelemetryEventTypes.AlertsGroupingTakeAction, params);
    });
    (0, _defineProperty2.default)(this, "reportAssistantInvoked", params => {
      this.analytics.reportEvent(_constants.TelemetryEventTypes.AssistantInvoked, params);
    });
    (0, _defineProperty2.default)(this, "reportAssistantMessageSent", params => {
      this.analytics.reportEvent(_constants.TelemetryEventTypes.AssistantMessageSent, params);
    });
    (0, _defineProperty2.default)(this, "reportAssistantQuickPrompt", params => {
      this.analytics.reportEvent(_constants.TelemetryEventTypes.AssistantQuickPrompt, params);
    });
    (0, _defineProperty2.default)(this, "reportAssistantSettingToggled", params => {
      this.analytics.reportEvent(_constants.TelemetryEventTypes.AssistantSettingToggled, params);
    });
    (0, _defineProperty2.default)(this, "reportEntityDetailsClicked", ({
      entity
    }) => {
      this.analytics.reportEvent(_constants.TelemetryEventTypes.EntityDetailsClicked, {
        entity
      });
    });
    (0, _defineProperty2.default)(this, "reportEntityAlertsClicked", ({
      entity
    }) => {
      this.analytics.reportEvent(_constants.TelemetryEventTypes.EntityAlertsClicked, {
        entity
      });
    });
    (0, _defineProperty2.default)(this, "reportEntityRiskFiltered", ({
      entity,
      selectedSeverity
    }) => {
      this.analytics.reportEvent(_constants.TelemetryEventTypes.EntityRiskFiltered, {
        entity,
        selectedSeverity
      });
    });
    (0, _defineProperty2.default)(this, "reportAssetCriticalityCsvPreviewGenerated", params => {
      this.analytics.reportEvent(_constants.TelemetryEventTypes.AssetCriticalityCsvPreviewGenerated, params);
    });
    (0, _defineProperty2.default)(this, "reportAssetCriticalityFileSelected", params => {
      this.analytics.reportEvent(_constants.TelemetryEventTypes.AssetCriticalityFileSelected, params);
    });
    (0, _defineProperty2.default)(this, "reportAssetCriticalityCsvImported", params => {
      this.analytics.reportEvent(_constants.TelemetryEventTypes.AssetCriticalityCsvImported, params);
    });
    (0, _defineProperty2.default)(this, "reportMLJobUpdate", params => {
      this.analytics.reportEvent(_constants.TelemetryEventTypes.MLJobUpdate, params);
    });
    (0, _defineProperty2.default)(this, "reportCellActionClicked", params => {
      this.analytics.reportEvent(_constants.TelemetryEventTypes.CellActionClicked, params);
    });
    (0, _defineProperty2.default)(this, "reportAnomaliesCountClicked", params => {
      this.analytics.reportEvent(_constants.TelemetryEventTypes.AnomaliesCountClicked, params);
    });
    (0, _defineProperty2.default)(this, "reportDataQualityIndexChecked", params => {
      this.analytics.reportEvent(_constants.TelemetryEventTypes.DataQualityIndexChecked, params);
    });
    (0, _defineProperty2.default)(this, "reportDataQualityCheckAllCompleted", params => {
      this.analytics.reportEvent(_constants.TelemetryEventTypes.DataQualityCheckAllCompleted, params);
    });
    (0, _defineProperty2.default)(this, "reportBreadcrumbClicked", ({
      title
    }) => {
      this.analytics.reportEvent(_constants.TelemetryEventTypes.BreadcrumbClicked, {
        title
      });
    });
    (0, _defineProperty2.default)(this, "reportDetailsFlyoutOpened", params => {
      this.analytics.reportEvent(_constants.TelemetryEventTypes.DetailsFlyoutOpened, params);
    });
    (0, _defineProperty2.default)(this, "reportDetailsFlyoutTabClicked", params => {
      this.analytics.reportEvent(_constants.TelemetryEventTypes.DetailsFlyoutTabClicked, params);
    });
    (0, _defineProperty2.default)(this, "reportOnboardingHubStepOpen", params => {
      this.analytics.reportEvent(_constants.TelemetryEventTypes.OnboardingHubStepOpen, params);
    });
    (0, _defineProperty2.default)(this, "reportOnboardingHubStepFinished", params => {
      this.analytics.reportEvent(_constants.TelemetryEventTypes.OnboardingHubStepFinished, params);
    });
    (0, _defineProperty2.default)(this, "reportOnboardingHubStepLinkClicked", params => {
      this.analytics.reportEvent(_constants.TelemetryEventTypes.OnboardingHubStepLinkClicked, params);
    });
    (0, _defineProperty2.default)(this, "reportManualRuleRunOpenModal", params => {
      this.analytics.reportEvent(_constants.TelemetryEventTypes.ManualRuleRunOpenModal, params);
    });
    (0, _defineProperty2.default)(this, "reportManualRuleRunExecute", params => {
      this.analytics.reportEvent(_constants.TelemetryEventTypes.ManualRuleRunExecute, params);
    });
    (0, _defineProperty2.default)(this, "reportManualRuleRunCancelJob", params => {
      this.analytics.reportEvent(_constants.TelemetryEventTypes.ManualRuleRunCancelJob, params);
    });
    (0, _defineProperty2.default)(this, "reportEventLogFilterByRunType", params => {
      this.analytics.reportEvent(_constants.TelemetryEventTypes.EventLogFilterByRunType, params);
    });
    (0, _defineProperty2.default)(this, "reportOpenNoteInExpandableFlyoutClicked", params => {
      this.analytics.reportEvent(_constants.TelemetryEventTypes.OpenNoteInExpandableFlyoutClicked, params);
    });
    (0, _defineProperty2.default)(this, "reportAddNoteFromExpandableFlyoutClicked", params => {
      this.analytics.reportEvent(_constants.TelemetryEventTypes.AddNoteFromExpandableFlyoutClicked, params);
    });
    this.analytics = analytics;
  }
  reportToggleRiskSummaryClicked(params) {
    this.analytics.reportEvent(_constants.TelemetryEventTypes.ToggleRiskSummaryClicked, params);
  }
  reportRiskInputsExpandedFlyoutOpened(params) {
    this.analytics.reportEvent(_constants.TelemetryEventTypes.RiskInputsExpandedFlyoutOpened, params);
  }
  reportAddRiskInputToTimelineClicked(params) {
    this.analytics.reportEvent(_constants.TelemetryEventTypes.AddRiskInputToTimelineClicked, params);
  }
  reportEventLogShowSourceEventDateRange(params) {
    this.analytics.reportEvent(_constants.TelemetryEventTypes.EventLogShowSourceEventDateRange, params);
  }
}
exports.TelemetryClient = TelemetryClient;