"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.PanelHeader = void 0;
var _eui = require("@elastic/eui");
var _react = _interopRequireWildcard(require("react"));
var _agent_type_integration = require("../../../common/components/endpoint/agents/agent_type_integration");
var _use_alert_response_actions_support = require("../../../common/hooks/endpoint/use_alert_response_actions_support");
var _translations = require("../../../common/translations");
var _context = require("./context");
var _test_ids = require("./test_ids");
var _flyout_header = require("../../shared/components/flyout_header");
var _endpoint = require("../../../common/components/endpoint");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

/**
 * Document details expandable right section header for the isolate host panel
 */
const PanelHeader = () => {
  const {
    isolateAction,
    dataFormattedForFieldBrowser: data
  } = (0, _context.useIsolateHostPanelContext)();
  const {
    isSupported: supportsResponseActions,
    details: {
      agentType
    }
  } = (0, _use_alert_response_actions_support.useAlertResponseActionsSupport)(data);
  const showTechPreviewBadge = (0, _react.useMemo)(() => {
    return supportsResponseActions && (agentType === 'sentinel_one' || agentType === 'crowdstrike');
  }, [agentType, supportsResponseActions]);
  const title = /*#__PURE__*/_react.default.createElement(_eui.EuiFlexGroup, {
    responsive: true,
    gutterSize: "s"
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
    grow: false,
    "data-test-subj": "flyoutHostIsolationHeaderTitle"
  }, isolateAction === 'isolateHost' ? _endpoint.ISOLATE_HOST : _endpoint.UNISOLATE_HOST, /*#__PURE__*/_react.default.createElement(_eui.EuiSpacer, {
    size: "s"
  }), /*#__PURE__*/_react.default.createElement(_agent_type_integration.AgentTypeIntegration, {
    agentType: agentType,
    layout: "horizontal",
    "data-test-subj": "flyoutHostIsolationHeaderIntegration"
  })), showTechPreviewBadge && /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
    grow: false
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiBetaBadge, {
    "data-test-subj": "flyoutHostIsolationHeaderBadge",
    label: _translations.TECHNICAL_PREVIEW,
    tooltipContent: _translations.TECHNICAL_PREVIEW_TOOLTIP
  })));
  return /*#__PURE__*/_react.default.createElement(_flyout_header.FlyoutHeader, null, /*#__PURE__*/_react.default.createElement(_eui.EuiTitle, {
    size: "s"
  }, /*#__PURE__*/_react.default.createElement("h4", {
    "data-test-subj": _test_ids.FLYOUT_HEADER_TITLE_TEST_ID
  }, title)));
};
exports.PanelHeader = PanelHeader;