"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useUnstableSecuritySolutionDataView = void 0;
var _react = require("react");
var _reactRedux = require("react-redux");
var _is_enabled = require("./is_enabled");
var _selectors = require("./redux/selectors");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

/**
 * WARN: FOR INTERNAL USE ONLY
 * This hook provides data for experimental Sourcerer replacement in Security Solution.
 * Do not use in client code as the API will change frequently.
 * It will be extended in the future, covering more and more functionality from the current sourcerer.
 */
const useUnstableSecuritySolutionDataView = (_scopeId, fallbackDataView) => {
  const dataView = (0, _reactRedux.useSelector)(_selectors.sourcererAdapterSelector);
  const dataViewWithFallbacks = (0, _react.useMemo)(() => {
    return {
      ...dataView,
      // NOTE: temporary values sourced from the fallback. Will be replaced in the near future.
      browserFields: fallbackDataView.browserFields,
      sourcererDataView: fallbackDataView.sourcererDataView
    };
  }, [dataView, fallbackDataView.browserFields, fallbackDataView.sourcererDataView]);
  return (0, _is_enabled.isExperimentalSourcererEnabled)() ? dataViewWithFallbacks : fallbackDataView;
};
exports.useUnstableSecuritySolutionDataView = useUnstableSecuritySolutionDataView;