"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useTimelineColumns = void 0;
var _react = require("react");
var _model = require("../../../../../sourcerer/store/model");
var _containers = require("../../../../../sourcerer/containers");
var _use_experimental_features = require("../../../../../common/hooks/use_experimental_features");
var _default_headers = require("../../body/column_headers/default_headers");
var _default_config = require("../../../../../detections/components/alerts_table/default_config");
var _default_headers2 = require("../../unified_components/default_headers");
var _utils = require("./utils");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const useTimelineColumns = columns => {
  const {
    browserFields
  } = (0, _containers.useSourcererDataView)(_model.SourcererScopeName.timeline);
  const unifiedComponentsInTimelineDisabled = (0, _use_experimental_features.useIsExperimentalFeatureEnabled)('unifiedComponentsInTimelineDisabled');
  const defaultColumns = (0, _react.useMemo)(() => !unifiedComponentsInTimelineDisabled ? _default_headers2.defaultUdtHeaders : _default_headers.defaultHeaders, [unifiedComponentsInTimelineDisabled]);
  const localColumns = (0, _react.useMemo)(() => columns !== null && columns !== void 0 ? columns : defaultColumns, [columns, defaultColumns]);
  const augmentedColumnHeaders = (0, _utils.memoizedGetTimelineColumnHeaders)(localColumns, browserFields, false);
  const timelineQueryFieldsFromColumns = (0, _react.useMemo)(() => {
    const columnFields = augmentedColumnHeaders.map(c => c.id);
    return [...columnFields, ..._default_config.requiredFieldsForActions];
  }, [augmentedColumnHeaders]);
  return (0, _react.useMemo)(() => ({
    defaultColumns,
    localColumns,
    augmentedColumnHeaders,
    timelineQueryFieldsFromColumns
  }), [augmentedColumnHeaders, defaultColumns, timelineQueryFieldsFromColumns, localColumns]);
};
exports.useTimelineColumns = useTimelineColumns;