"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.wrapSuppressedEsqlAlerts = void 0;
var _objectHash = _interopRequireDefault(require("object-hash"));
var _ruleDataUtils = require("@kbn/rule-data-utils");
var _reason_formatters = require("../utils/reason_formatters");
var _build_bulk_body = require("../factories/utils/build_bulk_body");
var _utils = require("../utils");
var _utils2 = require("./utils");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const wrapSuppressedEsqlAlerts = ({
  events,
  spaceId,
  completeRule,
  mergeStrategy,
  alertTimestampOverride,
  ruleExecutionLogger,
  publicBaseUrl,
  tuple,
  isRuleAggregating,
  primaryTimestamp,
  secondaryTimestamp
}) => {
  const wrapped = events.map((event, i) => {
    var _completeRule$rulePar, _event$_index;
    const combinedFields = {
      ...(event === null || event === void 0 ? void 0 : event.fields),
      ...event._source
    };
    const suppressionTerms = (0, _utils.getSuppressionTerms)({
      alertSuppression: completeRule === null || completeRule === void 0 ? void 0 : (_completeRule$rulePar = completeRule.ruleParams) === null || _completeRule$rulePar === void 0 ? void 0 : _completeRule$rulePar.alertSuppression,
      fields: combinedFields
    });
    const id = (0, _utils2.generateAlertId)({
      event,
      spaceId,
      completeRule,
      tuple,
      isRuleAggregating,
      index: i
    });
    const instanceId = (0, _objectHash.default)([suppressionTerms, completeRule.alertId, spaceId]);
    const baseAlert = (0, _build_bulk_body.buildBulkBody)(spaceId, completeRule, event, mergeStrategy, [], true, _reason_formatters.buildReasonMessageForNewTermsAlert, [], alertTimestampOverride, ruleExecutionLogger, id, publicBaseUrl);
    return {
      _id: id,
      _index: (_event$_index = event._index) !== null && _event$_index !== void 0 ? _event$_index : '',
      _source: {
        ...baseAlert,
        ...(0, _utils.getSuppressionAlertFields)({
          primaryTimestamp,
          secondaryTimestamp,
          fields: combinedFields,
          suppressionTerms,
          fallbackTimestamp: baseAlert[_ruleDataUtils.TIMESTAMP],
          instanceId
        })
      }
    };
  });
  return wrapped;
};
exports.wrapSuppressedEsqlAlerts = wrapSuppressedEsqlAlerts;