"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createIndex = void 0;
var _securitysolutionEsUtils = require("@kbn/securitysolution-es-utils");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const createIndex = async ({
  esClient,
  logger,
  options
}) => {
  try {
    await esClient.indices.create({
      index: options.index,
      mappings: typeof options.mappings === 'string' ? JSON.parse(options.mappings) : options.mappings
    });
    return {
      [options.index]: {
        success: true,
        error: null
      }
    };
  } catch (err) {
    const error = (0, _securitysolutionEsUtils.transformError)(err);
    logger.error(`Failed to create index: ${options.index}: ${error.message}`);
    return {
      [options.index]: {
        success: false,
        error
      }
    };
  }
};
exports.createIndex = createIndex;