"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ConnectorsOverview = void 0;
var _eui = require("@elastic/eui");
var _i18n = require("@kbn/i18n");
var _i18nReact = require("@kbn/i18n-react");
var _react = _interopRequireWildcard(require("react"));
var _i18n_string = require("../../../common/i18n_string");
var _common = require("../../../common");
var _use_connectors = require("../hooks/api/use_connectors");
var _use_create_connector = require("../hooks/api/use_create_connector");
var _use_kibana = require("../hooks/use_kibana");
var _empty_connectors_prompt = require("./connectors/empty_connectors_prompt");
var _connectors_table = require("./connectors/connectors_table");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const ConnectorsOverview = () => {
  const {
    data,
    isLoading: connectorsLoading
  } = (0, _use_connectors.useConnectors)();
  const {
    http,
    console: consolePlugin
  } = (0, _use_kibana.useKibanaServices)();
  const {
    createConnector,
    isLoading
  } = (0, _use_create_connector.useCreateConnector)();
  const embeddableConsole = (0, _react.useMemo)(() => consolePlugin !== null && consolePlugin !== void 0 && consolePlugin.EmbeddableConsole ? /*#__PURE__*/_react.default.createElement(consolePlugin.EmbeddableConsole, null) : null, [consolePlugin]);
  return /*#__PURE__*/_react.default.createElement(_eui.EuiPageTemplate, {
    offset: 0,
    grow: true,
    restrictWidth: true,
    "data-test-subj": "svlSearchConnectorsPage"
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiPageTemplate.Header, {
    pageTitle: _i18n.i18n.translate('xpack.serverlessSearch.connectors.title', {
      defaultMessage: 'Connectors'
    }),
    "data-test-subj": "serverlessSearchConnectorsTitle",
    restrictWidth: true,
    rightSideItems: [/*#__PURE__*/_react.default.createElement(_eui.EuiFlexGroup, {
      direction: "row",
      alignItems: "flexStart",
      justifyContent: "center"
    }, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, null, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexGroup, {
      alignItems: "center",
      gutterSize: "xs",
      justifyContent: "flexEnd",
      direction: "row"
    }, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
      grow: false
    }, /*#__PURE__*/_react.default.createElement(_eui.EuiIcon, {
      size: "s",
      type: http.basePath.prepend(`/plugins/${_common.PLUGIN_ID}/assets/github.svg`)
    })), /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
      grow: false
    }, /*#__PURE__*/_react.default.createElement(_eui.EuiText, {
      size: "s"
    }, /*#__PURE__*/_react.default.createElement(_eui.EuiLink, {
      "data-test-subj": "serverlessSearchConnectorsOverviewElasticConnectorsLink",
      target: "_blank",
      href: "https://github.com/elastic/connectors"
    }, _i18n.i18n.translate('xpack.serverlessSearch.connectorsPythonLink', {
      defaultMessage: 'elastic/connectors'
    })))))), /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, null, /*#__PURE__*/_react.default.createElement(_eui.EuiButton, {
      "data-test-subj": "serverlessSearchConnectorsOverviewCreateConnectorButton",
      isLoading: isLoading,
      fill: true,
      iconType: "plusInCircleFilled",
      onClick: () => createConnector()
    }, _i18n.i18n.translate('xpack.serverlessSearch.connectors.createConnector', {
      defaultMessage: 'Create connector'
    }))))]
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiText, null, /*#__PURE__*/_react.default.createElement("p", null, /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
    id: "xpack.serverlessSearch.connectors.headerContent",
    defaultMessage: "Sync third-party data sources to Elasticsearch, by deploying Elastic connectors on your own infrastructure. {learnMoreLink}",
    values: {
      learnMoreLink: /*#__PURE__*/_react.default.createElement(_eui.EuiLink, {
        "data-test-subj": "serverlessSearchConnectorsOverviewLink",
        external: true,
        target: "_blank",
        href: 'TODO TODO'
      }, _i18n_string.LEARN_MORE_LABEL)
    }
  })))), connectorsLoading || ((data === null || data === void 0 ? void 0 : data.connectors) || []).length > 0 ? /*#__PURE__*/_react.default.createElement(_eui.EuiPageTemplate.Section, {
    restrictWidth: true,
    color: "subdued"
  }, /*#__PURE__*/_react.default.createElement(_connectors_table.ConnectorsTable, null)) : /*#__PURE__*/_react.default.createElement(_eui.EuiPageTemplate.Section, {
    restrictWidth: true,
    color: "subdued"
  }, /*#__PURE__*/_react.default.createElement(_empty_connectors_prompt.EmptyConnectorsPrompt, null)), embeddableConsole);
};
exports.ConnectorsOverview = ConnectorsOverview;