"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.SolutionView = void 0;
var _eui = require("@elastic/eui");
var _react = _interopRequireDefault(require("react"));
var _i18n = require("@kbn/i18n");
var _i18nReact = require("@kbn/i18n-react");
var _section_panel = require("../section_panel");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const getOptions = ({
  size
}) => {
  const iconCss = {
    marginRight: size.m
  };
  return [{
    value: 'es',
    inputDisplay: /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_eui.EuiIcon, {
      type: "logoElasticsearch",
      css: iconCss
    }), _i18n.i18n.translate('xpack.spaces.management.manageSpacePage.solutionViewSelect.searchOptionLabel', {
      defaultMessage: 'Search'
    })),
    'data-test-subj': 'solutionViewEsOption'
  }, {
    value: 'oblt',
    inputDisplay: /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_eui.EuiIcon, {
      type: "logoObservability",
      css: iconCss
    }), _i18n.i18n.translate('xpack.spaces.management.manageSpacePage.solutionViewSelect.obltOptionLabel', {
      defaultMessage: 'Observability'
    })),
    'data-test-subj': 'solutionViewObltOption'
  }, {
    value: 'security',
    inputDisplay: /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_eui.EuiIcon, {
      type: "logoSecurity",
      css: iconCss
    }), _i18n.i18n.translate('xpack.spaces.management.manageSpacePage.solutionViewSelect.securityOptionLabel', {
      defaultMessage: 'Security'
    })),
    'data-test-subj': 'solutionViewSecurityOption'
  }, {
    value: 'classic',
    inputDisplay: /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_eui.EuiIcon, {
      type: "logoKibana",
      css: iconCss
    }), _i18n.i18n.translate('xpack.spaces.management.manageSpacePage.solutionViewSelect.classicOptionLabel', {
      defaultMessage: 'Classic'
    })),
    'data-test-subj': 'solutionViewClassicOption'
  }];
};
const SolutionView = ({
  space,
  onChange
}) => {
  const {
    euiTheme
  } = (0, _eui.useEuiTheme)();
  return /*#__PURE__*/_react.default.createElement(_section_panel.SectionPanel, {
    title: _i18n.i18n.translate('xpack.spaces.management.manageSpacePage.navigationTitle', {
      defaultMessage: 'Navigation'
    }),
    dataTestSubj: "navigationPanel"
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexGroup, null, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, null, /*#__PURE__*/_react.default.createElement(_eui.EuiTitle, {
    size: "xs"
  }, /*#__PURE__*/_react.default.createElement("h3", null, /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
    id: "xpack.spaces.management.manageSpacePage.setSolutionViewMessage",
    defaultMessage: "Set solution view"
  }))), /*#__PURE__*/_react.default.createElement(_eui.EuiSpacer, {
    size: "s"
  }), /*#__PURE__*/_react.default.createElement(_eui.EuiText, {
    size: "s",
    color: "subdued"
  }, /*#__PURE__*/_react.default.createElement("p", null, /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
    id: "xpack.spaces.management.manageSpacePage.setSolutionViewDescription",
    defaultMessage: "Determines the navigation all users will see for this space. Each solution view contains features from Analytics tools and Management."
  })))), /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, null, /*#__PURE__*/_react.default.createElement(_eui.EuiFormRow, {
    label: _i18n.i18n.translate('xpack.spaces.management.navigation.solutionViewLabel', {
      defaultMessage: 'Solution view'
    }),
    fullWidth: true
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiSuperSelect, {
    options: getOptions(euiTheme),
    valueOfSelected: space.solution,
    "data-test-subj": "solutionViewSelect",
    onChange: solution => {
      onChange({
        ...space,
        solution
      });
    }
  })))));
};
exports.SolutionView = SolutionView;