"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.cancelableTimedPromise = void 0;
const errors_1 = require("../errors");
/**
 * Returns a promise which errors after t seconds.
 *
 * @param t Timeout in seconds.
 * @param taskName Name of task being timed for logging and error reporting.
 */
function cancelableTimedPromise(t, taskName) {
    let timeout;
    let resolve;
    const promise = new Promise((_res, reject) => {
        resolve = _res;
        timeout = setTimeout(() => {
            const e = `${taskName} timed out after ${t} seconds.`;
            reject(new errors_1.LDTimeoutError(e));
        }, t * 1000);
    });
    return {
        promise,
        cancel: () => {
            resolve();
            clearTimeout(timeout);
        },
    };
}
exports.cancelableTimedPromise = cancelableTimedPromise;
//# sourceMappingURL=cancelableTimedPromise.js.map